Crate trame_runtime

Crate trame_runtime 

All traits used to represent a runtime on which trame can operate.

Re-exports

pub use verified::VLayout;
pub use verified::VLayoutError;

Modules

live
Live implementations of all of trame’s runtime traits: no verification involved, real memory allocations, etc.
verified
Verified implementations of all of trame’s runtime traits: storage is heavily bounded, all operations are checked, we track a lot of things.

Structs

Idx
A typed index into an arena.

Traits

IArena
Arena for allocating and managing items.
IField
Interface for field information.
IHeap
Heap for memory operations, generic over shape type.
IPtr
Pointer type
IRuntime
A heap and a shape implementation, over which Trame can be parameterized
IShape
Common interface for shapes.
IShapeExtra
IShapeStore
A store of shapes that can be looked up by handle.
IStructType
Interface for struct type information.
LiveRuntime
Marker trait for runtimes that use real facet shapes and raw pointers.