IPtr

Trait IPtr 

pub trait IPtr: Copy {
    // Required method
    unsafe fn byte_add(self, n: usize) -> Self;
}
Pointer type

Required Methods

unsafe fn byte_add(self, n: usize) -> Self

Compute a new pointer at a byte offset from this one.

Safety

The caller must ensure the resulting pointer is in-bounds.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IPtr for *mut u8

Available on non-creusot only.
Source

unsafe fn byte_add(self, n: usize) -> Self

Implementors