pub fn vshape_view(handle: VShapeHandle) -> VShapeView<'static, VShapeStore>Expand description
View a previously registered shape from the global store.
pub fn vshape_view(handle: VShapeHandle) -> VShapeView<'static, VShapeStore>View a previously registered shape from the global store.