VShapeDef

Struct VShapeDef 

pub struct VShapeDef {
    pub layout: VLayout,
    pub def: VDef,
}
A bounded shape definition for Kani verification.

Unlike facet_core::Shape which uses static references and can be recursive, these shapes are bounded and can implement kani::Arbitrary.

Shape definitions live in a DynShapeStore and are referenced by handle.

Fields

layout: VLayout

Layout of this type.

def: VDef

Type-specific information.

Implementations

Source

impl VShapeDef

pub const fn scalar(layout: VLayout) -> Self

Create a scalar shape with the given layout.

pub fn struct_with_fields( store: &VShapeStore, fields: &[(usize, VShapeHandle)], ) -> Self

Create a struct shape with the given fields.

The field_shapes parameter provides the shape handle for each field. Use store.get_def(handle).layout to get layouts for size calculation.