VShapeStore

Struct VShapeStore 

pub struct VShapeStore {
    pub shape_count: u8,
    pub shapes: [VShapeDef; 8],
}
A store of DynShape definitions.

Shapes are stored in an array and referenced by index (DynShapeHandle). This allows shapes to reference other shapes (nested structs) without creating recursive type definitions.

Fields

shape_count: u8

Number of shapes in the store.

shapes: [VShapeDef; 8]

Shape definitions (only first shape_count entries are valid).

Implementations

Source

impl VShapeStore

pub const fn new() -> Self

Create a new empty store.

pub fn add(&mut self, shape: VShapeDef) -> VShapeHandle

Add a shape to the store and return its handle.

pub fn get_def(&self, handle: VShapeHandle) -> &VShapeDef

Get a shape definition by handle.

pub fn view(&self, handle: VShapeHandle) -> VShapeView<'_, Self>

Get a view into a shape.