VShapeView

Struct VShapeView 

pub struct VShapeView<'a, Store: IShapeStore> {
    pub store: &'a Store,
    pub handle: Store::Handle,
}
A view into a shape, borrowing from a store.

This is the common currency for working with shapes in the verified runtime.

Fields

store: &'a Storehandle: Store::Handle