Verified implementations of all of trame’s runtime traits: storage is heavily bounded, all operations are checked, we track a lot of things.
Structs
- Alloc
History - History of operations for one allocation.
- HeapOp
- An operation that was performed on an allocation.
- VArena
- Fixed-size arena for Kani verification.
- VField
Def - A synthetic field for Kani verification.
- VField
View - A field view that borrows from a store.
- VHeap
- Verified heap that tracks state for Kani proofs.
- VPtr
- Fat pointer for verified heap operations.
- VRuntime
- A runtime that verifies all operations
- VShape
Def - A bounded shape definition for Kani verification.
- VShape
Handle - A handle to a shape in a DynShapeStore.
- VShape
Store - A store of DynShape definitions.
- VShape
View - A view into a shape, borrowing from a store.
- VStruct
Def - A synthetic struct type for Kani verification.
- VStruct
View - A struct type view that borrows from a store.
Enums
- Heap
OpKind - The kind of heap operation.
- VDef
- Type-specific definition for verified shapes.
- VHeap
Error - Error from heap operations.
Constants
- MAX_
FIELDS_ PER_ STRUCT - Maximum number of fields in a struct (for bounded verification).
- MAX_
SHAPES_ PER_ STORE - Maximum number of shapes in a store (for bounded verification).
- MAX_
VARENA_ SLOTS - Maximum number of arena slots for verification.
- MAX_
VHEAP_ ALLOCS - Maximum number of allocations tracked by VHeap.
Functions
- vshape_
register - Register a new verified shape in the global store.
- vshape_
store - vshape_
store_ ⚠reset - Reset the global shape store. For testing only.
- vshape_
view - View a previously registered shape from the global store.