pub struct VShapeView<'a, Store: IShapeStore> {
pub store: &'a Store,
pub handle: Store::Handle,
}Expand description
A view into a shape, borrowing from a store.
This is the common currency for working with shapes in the verified runtime.
Fields
store: &'a Storehandle: Store::HandleTrait Implementations
Sourceimpl<'a, Store: Clone + IShapeStore> Clone for VShapeView<'a, Store>
impl<'a, Store: Clone + IShapeStore> Clone for VShapeView<'a, Store>
Sourcefn clone(&self) -> VShapeView<'a, Store>
fn clone(&self) -> VShapeView<'a, Store>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<'a, Store: Copy + IShapeStore> Copy for VShapeView<'a, Store>
impl<'a> Eq for VShapeView<'a, VShapeStore>
Sourceimpl<'a> IShape for VShapeView<'a, VShapeStore>
impl<'a> IShape for VShapeView<'a, VShapeStore>
Sourcetype StructType = VStructView<'a>
type StructType = VStructView<'a>
The struct type returned by
as_struct().Sourcetype Field = VFieldView<'a>
type Field = VFieldView<'a>
The field type used by struct types.
Sourcefn layout(&self) -> Option<Layout>
fn layout(&self) -> Option<Layout>
Get the layout (size and alignment) of this shape. Read more
Sourcefn as_struct(&self) -> Option<Self::StructType>
fn as_struct(&self) -> Option<Self::StructType>
Get struct-specific information, if this is a struct.
Sourceimpl<'a> PartialEq for VShapeView<'a, VShapeStore>
impl<'a> PartialEq for VShapeView<'a, VShapeStore>